module VDACif( input clk108,
					input hstart,
					input vstart,					
					input hblank,
					input vblank,
					input VSYNCout,
					input [9:0] X1,			//horizontal component of line data
					input [8:0] Y1,
					output reg [9:0] X = 0,							//horizontal counter
					output reg [8:0] Y = 0,							//vertical counter
					output reg [9:0] Z = 0,							//diagonal counter
					output reg [4:0] Red_data = 0,
					output reg [5:0] Green_data = 0,
					output reg [4:0] Blue_data = 0,
					output reg DACBLANKn = 1,
					output reg countflag
					);

parameter
Xmax = 640,
Ymax = 480,
Zmax = 800;									//diagonal max

always @(posedge clk108)
      if ( hstart )
         countflag <= 1;				//countflag active in display area
      else if ( hblank )
         countflag <= 0;
			
always @(posedge clk108)
	if ( countflag )
		X <= X + 1;							//count horizontal position inside the border
		else 
			X <= 0;

always @(posedge clk108)				//
	 if ( Y == Ymax )
			Y <= 0;
		else if ( X == Xmax )		
			Y <= Y + 1;
						
always @(posedge clk108)								//outgoing data to videoDAC	
	if ( countflag & ( X == X1 | Y == Y1 )) begin
		Z <= Z + 1;
		Red_data <= 0;
		Green_data <= 6'b111111;
		Blue_data <= 0;									//Priority 1, plot green pixel 
	end
		else if ( Z == Zmax )
			Z <= 0;
		else if ( vblank & VSYNCout ) begin			
			Red_data <= 0;
			Green_data <= 0;
			Blue_data <= 0;								//send black during vertical retrace
		end
		else if ( !countflag ) begin
			Red_data <= 0;
			Green_data <= 0;
			Blue_data <= 5'b11111;						//Priority 2, blue border
		end
		else if ( X[0] ) begin				
			Red_data <= 5'b11111;		
			Green_data <= 0;
			Blue_data <= 0;								//Priority 3, odd pixels red
		end
	else begin				
		Red_data <= 0;
		Green_data <= 0;
		Blue_data <= 5'b11111;							//Priority 4, even pixels blue
	end
	
endmodule



